@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
 
-from .testing import HttpServerTest, HttpsServerTest
+from .testing import HttpTestServer, HttpsTestServer
 from .server import (Server, start_server, start_ssl_server, http_server,
                      https_server)
 
 
-__all__ = ['HttpServerTest', 'HttpsServerTest', 'Server', 'start_server',
+__all__ = ['HttpTestServer', 'HttpsTestServer', 'Server', 'start_server',
            'start_ssl_server', 'http_server', 'https_server']
