@@ -4,20 +4,26 @@ from .server import start_server, start_ssl_server
 
 
 class ServerBase(object):
-    """Base para tests de server"""
+    """Base class for all the server mixins"""
+
+    server = None
+    """Class level server instance"""
+
+    default_path = '/testing/this'
+    """Path for default url"""
+
     def url(self, path):
+        """Returns full urls for the server from a path"""
         return self.server.url(path)
 
-    @property
-    def default_path(self):
-        return '/testing/this'
-
     @property
     def default_url(self):
+        """Default url for testing"""
         return self.url(self.default_path)
 
 
-class HttpServerTest(ServerBase):
+class HttpTestServer(ServerBase):
+    """Mixin class for testing using an http server"""
     options = {}
 
     @classmethod
@@ -25,7 +31,8 @@ class HttpServerTest(ServerBase):
         cls.server = start_server()
 
 
-class HttpsServerTest(ServerBase):
+class HttpsTestServer(ServerBase):
+    """Mixin class for testing using an https server"""
     options = {'verify': False}
 
     @classmethod
